pub trait TryFromBeBytes: Sized {
const SIZE: usize;
// Required method
fn try_parse_from_be_bytes(data: &[u8]) -> Option<Self>;
}Expand description
A trait for parsing raw binary data of fixed size.
This is a low-level, internal trait that should not be used directly.
Required Associated Constants
Required Methods
Sourcefn try_parse_from_be_bytes(data: &[u8]) -> Option<Self>
fn try_parse_from_be_bytes(data: &[u8]) -> Option<Self>
Parses an object from a raw data.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".